CAMView
=======

 Android view component to display the live picture from device camera and optionally provide developer with the 
 preview data for any external decoding processes within application.

 The main goal of this project is to have a simple and clean view component which can be easily put to an existing
 view hierarchy of any existing activity, fragment or just to a layout file like any other Android component such as
 TextView, ImageView, etc. 
 
 CAMView takes all dirty job for handling all routines for a camera initialization, configuration, streaming, 
 orientation changes, device and cameras compatibility options, etc, etc. So just put it to your layout and you're armed
 with the live picture from the camera.


Status
======

- Current stable version: 1.1.0
- Current development version: 2.0.0-SNAPSHOT

 Please feel free to share your comments and suggestions, report any bugs or submit your pull requests 
 (second is even better :)

Note, 1.x branch is the last one, supports Android 2.x SDK. Branch 2.x will be focused for 4.0+ SDK only, while
1.x branch will be on maintenance for critical bugs only.


Get It
======

- Maven repository: http://maven.livotovlabs.pro/content/groups/public
- Group: eu.livotov.labs
- Artifact ID: camview

```groovy

repositories {
    ...
    maven { url 'http://maven.livotovlabs.pro/content/groups/public' }
    ...
}


compile group: "eu.livotov.labs", name: "camview", version: "1.1.0", ext: "aar"

```

Usage
=====
          
 Usage is very straightforward - just add this component to your layout.xml (or programmatically at runtiume)
 and invoke the start() method when you need to start displaying the live stream from the camera:


 1. Add to layout

 ```
 <?xml version="1.0" encoding="utf-8"?>
 <FrameLayout xmlns:android="http://schemas.android.com/apk/res/android"
              android:layout_width="match_parent"
              android:layout_height="match_parent"
         >

     ...

     <eu.livotov.labs.android.camview.CAMView
             android:id="@+id/my_camera_view"
             android:layout_width="match_parent"
             android:layout_height="match_parent"
             android:layout_gravity="center"/>

     ...

 </FrameLayout>
 ```


 2. Get the CAMView instance

 ```
 cameraView = (CAMView) findViewById(R.id.my_camera_view);
 ```


 3. Begin streaming live picture from the default camera.

 ```
 cameraView.start();
 ```


 3.1 Or, if you need to work with the specific camera:

 ```
 // Get the list of availabvle cameras
 Collection<CameraEnumeration> allCams = cameraView.enumerateCameras();

 // Start streaming with the specific camera id:
 cameraView.start(allCams.get(somePosition).getCameraId());
 ```

 3.2 Control flash, if required
 
 ```
    cameraView.switchFlash(boolean onoff);
 ```
 
 4. If you need to process live data from the camera during the live streaming process (for instance, 
    for a barcode recognition) - just enable this and use the listener callback:

 ```
     cameraView.setCaptureStreamingFrames(true);
     cameraView.setCamViewListener(this);
     
     ... 
     
     public void onPreviewData(final byte[] data, final int previewFormat, final Camera.Size size)
     {
         // do smth with the frame from the camera here - it comes directly from the SurfaceView object,
         so deal with the data as usual.
     }
 ```
   Do not forget to disable preview frames capturing when you don't need them anymore - this will reduce load
   to device CPU and memory. You may enable capturing back at any time, once you need it again.
   
 ```
   cameraView.setCaptureStreamingFrames(false);
 ```  


 5. Stop streaming from the camera

 ```
 cameraView.stop();
 ```
